summaryrefslogtreecommitdiffstats
path: root/kpilot/kpilot/pilotComponent.cc
diff options
context:
space:
mode:
Diffstat (limited to 'kpilot/kpilot/pilotComponent.cc')
-rw-r--r--kpilot/kpilot/pilotComponent.cc20
1 files changed, 10 insertions, 10 deletions
diff --git a/kpilot/kpilot/pilotComponent.cc b/kpilot/kpilot/pilotComponent.cc
index 414db70e..0172a44e 100644
--- a/kpilot/kpilot/pilotComponent.cc
+++ b/kpilot/kpilot/pilotComponent.cc
@@ -35,8 +35,8 @@
#include <pi-appinfo.h>
-#include <qwidget.h>
-#include <qcombobox.h>
+#include <tqwidget.h>
+#include <tqcombobox.h>
#include <kdebug.h>
@@ -46,10 +46,10 @@
#include "pilotComponent.moc"
-PilotComponent::PilotComponent(QWidget * parent,
+PilotComponent::PilotComponent(TQWidget * parent,
const char *id,
- const QString & path) :
- QWidget(parent, id),
+ const TQString & path) :
+ TQWidget(parent, id),
fDBPath(path),
shown(false)
{
@@ -65,7 +65,7 @@ PilotComponent::PilotComponent(QWidget * parent,
-int PilotComponent::findSelectedCategory(QComboBox * fCatList,
+int PilotComponent::findSelectedCategory(TQComboBox * fCatList,
struct CategoryAppInfo *info, bool AllIsUnfiled)
{
FUNCTIONSETUP;
@@ -101,7 +101,7 @@ int PilotComponent::findSelectedCategory(QComboBox * fCatList,
}
else
{
- QString selectedCategory =
+ TQString selectedCategory =
fCatList->text(fCatList->currentItem());
currentCatID = Pilot::findCategory(info, selectedCategory, AllIsUnfiled);
}
@@ -112,7 +112,7 @@ int PilotComponent::findSelectedCategory(QComboBox * fCatList,
}
-void PilotComponent::populateCategories(QComboBox * c,
+void PilotComponent::populateCategories(TQComboBox * c,
struct CategoryAppInfo *info)
{
FUNCTIONSETUP;
@@ -165,14 +165,14 @@ void PilotComponent::slotShowComponent()
emit showComponent(this);
}
/* virtual */ bool PilotComponent::preHotSync(QString &)
{
FUNCTIONSETUP;
return true;
}
-void PilotComponent::markDBDirty(const QString db)
+void PilotComponent::markDBDirty(const TQString db)
{
FUNCTIONSETUP;
KPilotConfig::addDirtyDatabase(db);
@@ -165,14 +165,14 @@ void PilotComponent::slotShowComponent()
emit showComponent(this);
}
-/* virtual */ bool PilotComponent::preHotSync(QString &)
+/* virtual */ bool PilotComponent::preHotSync(TQString &)
{
FUNCTIONSETUP;